======
Models
======

Model objects are used for composing models that are fitted to data.

It is recommended the `model API cookbooks <https://pyautofit.readthedocs.io/en/latest/cookbooks/cookbook_1_basics.html>`_ are used for guidance on building complex model.

**Examples / Tutorials:**

- `Model API Cookbooks (recommended) <https://pyautofit.readthedocs.io/en/latest/cookbooks/cookbook_1_basics.html>`_.

- `readthedocs: example using Model object <https://pyautofit.readthedocs.io/en/latest/overview/model_fit.html>`_.
- `readthedocs: example using Collection object <https://pyautofit.readthedocs.io/en/latest/overview/model_complex.html>`_.
- `autofit_workspace: simple tutorial <https://github.com/Jammy2211/autofit_workspace/blob/release/notebooks/overview/simple/fit.ipynb>`_
- `autofit_workspace: complex tutorial <https://github.com/Jammy2211/autofit_workspace/blob/release/notebooks/overview/complex/fit.ipynb>`_
- `HowToFit: introduction chapter (detailed step-by-step examples) <https://pyautofit.readthedocs.io/en/latest/howtofit/chapter_1_introduction.html>`_

------
Models
------

.. currentmodule:: autofit

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:

   Model
   Collection